#!/usr/bin/gnuplot

cm = 1.e-2
R_S = 6.955e8
deg = pi/180.
arcsec = deg/3600.
mas = 1.e-3*arcsec
AU = 1.49597870700e11
pc = 648000.0/pi*AU

load "config.plt"

omega_an = omega_an*deg
dd = dd*pc
xb = -qq*sma/(1.0+qq)

e(x) = x*cm/R_S
f(x,y) = (e(x)-xb)*cos(-omega_an-90*deg) - e(y)*sin(-omega_an-90*deg)
g(x,y) = -((e(x)-xb)*sin(-omega_an-90*deg) + e(y)*cos(-omega_an-90*deg))

########################################################################

set term post eps enh color solid "Helvetica" 18
set out "img.eps"

#set xl "{/Symbol Da} [mas]"
set yl "{/Symbol Dd} [mas]"
set cbl "{/Helvetica-Oblique I}_{/Symbol n} [erg cm^{-2} s^{-1} Hz^{-1} sr^{-1}]" offset +2,0

tmp=1.2
set xr [-tmp:tmp]
set yr [-tmp:tmp]
load "lambda.plt"
set cbr [0:cb2]

set xtics format ""
set cbtics format "%.1t{\264}10^{%T}"
set pm3d map
set size ratio -1
set nokey
set border lc rgb "white"
set tics tc rgb "black"
set cbtics tc rgb "black"

load "moreland.pal"

set label sprintf("{/Symbol l} = %5.0f A", lambda) at graph 0.65,0.9 tc rgb "white" front

splot \
  0,\
  "<cat 2Dimage_001" u (f($1,$2)*R_S/dd/mas):(g($1,$2)*R_S/dd/mas):3


